==> mongodb-src-r4.0.9.tar.gz: mongodb-src-r4.0.9/src/mongo/db/storage/mobile/mobile_global_options.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <string>

#include "mongo/base/status.h"
#include "mongo/util/options_parser/environment.h"

namespace mongo {

class MobileGlobalOptions {
public:
    MobileGlobalOptions() : mobileDurabilityLevel(1){};

    Status store(const optionenvironment::Environment& params);

    // This is used by the Mobile SE and allows users to set the value
    // passed to SQLite's PRAGMA synchronous command
    std::int32_t mobileDurabilityLevel;
};

extern MobileGlobalOptions mobileGlobalOptions;

}  // namespace mongo

==> mongodb-src-r4.0.11.tar.gz: mongodb-src-r4.0.11/src/mongo/db/storage/mobile/mobile_global_options.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <string>

#include "mongo/base/status.h"
#include "mongo/util/options_parser/environment.h"

namespace mongo {

class MobileGlobalOptions {
public:
    MobileGlobalOptions() : mobileDurabilityLevel(1){};

    Status store(const optionenvironment::Environment& params);

    // This is used by the Mobile SE and allows users to set the value
    // passed to SQLite's PRAGMA synchronous command
    std::uint32_t mobileDurabilityLevel;
};

extern MobileGlobalOptions mobileGlobalOptions;

}  // namespace mongo
